==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/AttachedVolumeFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class AttachedVolumeFluentImpl<A extends AttachedVolumeFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements AttachedVolumeFluent<A>{

    private String devicePath;
    private String name;

    public AttachedVolumeFluentImpl(){
    }
    public AttachedVolumeFluentImpl(AttachedVolume instance){
            this.withDevicePath(instance.getDevicePath()); 
            this.withName(instance.getName()); 
    }

    public String getDevicePath(){
            return this.devicePath;
    }

    public A withDevicePath(String devicePath){
            this.devicePath=devicePath; return (A) this;
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            AttachedVolumeFluentImpl that = (AttachedVolumeFluentImpl) o;
            if (devicePath != null ? !devicePath.equals(that.devicePath) :that.devicePath != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            return true;
    }




}

==> kubernetes-model-4.5.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/AttachedVolumeFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class AttachedVolumeFluentImpl<A extends AttachedVolumeFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements AttachedVolumeFluent<A>{

    private String devicePath;
    private String name;

    public AttachedVolumeFluentImpl(){
    }
    public AttachedVolumeFluentImpl(AttachedVolume instance){
            this.withDevicePath(instance.getDevicePath()); 
            this.withName(instance.getName()); 
    }

    public String getDevicePath(){
            return this.devicePath;
    }

    public A withDevicePath(String devicePath){
            this.devicePath=devicePath; return (A) this;
    }

    public Boolean hasDevicePath(){
            return this.devicePath != null;
    }

    public A withNewDevicePath(String arg1){
            return (A)withDevicePath(new String(arg1));
    }

    public A withNewDevicePath(StringBuilder arg1){
            return (A)withDevicePath(new String(arg1));
    }

    public A withNewDevicePath(StringBuffer arg1){
            return (A)withDevicePath(new String(arg1));
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            AttachedVolumeFluentImpl that = (AttachedVolumeFluentImpl) o;
            if (devicePath != null ? !devicePath.equals(that.devicePath) :that.devicePath != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            return true;
    }




}
